.. image:: https://travis-ci.org/cdumay/flask-openldap.svg?branch=master
    :target: https://travis-ci.org/cdumay/flask-openldap

flask-openldap
==============

Flask extension to query an openLDAP server using `Flask-SimpleLDAP <https://github.com/admiralobvious/flask-simpleldap>`_.

License
-------

Apache License 2.0